@@ -1,12 +1,16 @@
+from __future__ import annotations
+
 import asyncio
 from functools import wraps
 from threading import Thread
 from queue import Queue as SyncQueue
+from idom.core.proto import ComponentType
 
 import ipywidgets as widgets
 from IPython.display import display as ipython_display
 from traitlets import Unicode
 from idom.core.layout import Layout, LayoutEvent, LayoutUpdate
+from idom.core.dispatcher import VdomJsonPatch, render_json_patch
 
 
 _JUPYTER_SERVER_BASE_URL = ""
@@ -58,25 +62,25 @@ class LayoutWidget(widgets.DOMWidget):
 
     _jupyter_server_base_url = Unicode().tag(sync=True)
 
-    def __init__(self, element):
+    def __init__(self, component: ComponentType):
         super().__init__(_jupyter_server_base_url=_JUPYTER_SERVER_BASE_URL)
         self._idom_model = {}
         self._idom_views = set()
-        self._idom_layout = Layout(element)
+        self._idom_layout = Layout(component)
         self._idom_loop = _spawn_threaded_event_loop(self._idom_layout_render_loop())
-        self.on_msg(self._idom_on_msg)
+        self.on_msg(lambda _, *args, **kwargs: self._idom_on_msg(*args, **kwargs))
 
-    @staticmethod
     def _idom_on_msg(self, message, buffers):
         m_type = message.get("type")
         if m_type == "client-ready":
             v_id = message["viewID"]
             self._idom_views.add(v_id)
-            update = LayoutUpdate.create_from({}, self._idom_model)
-            self.send({"viewID": v_id, "data": update})
+            update = LayoutUpdate("", None, self._idom_model)
+            diff = VdomJsonPatch.create_from(update)
+            self.send({"viewID": v_id, "data": diff})
         elif m_type == "dom-event":
             asyncio.run_coroutine_threadsafe(
-                self._idom_layout.dispatch(LayoutEvent(**message["data"])),
+                self._idom_layout.deliver(LayoutEvent(**message["data"])),
                 loop=self._idom_loop,
             )
         elif m_type == "client-removed":
@@ -85,13 +89,15 @@ class LayoutWidget(widgets.DOMWidget):
                 self._idom_views.remove(message["viewID"])
 
     async def _idom_layout_render_loop(self):
-        async with self._idom_layout:
+        with self._idom_layout:
             while True:
-                update = await self._idom_layout.render()
-
-                self._idom_model = update.apply_to(self._idom_model)
+                diff = await render_json_patch(self._idom_layout)
+                self._idom_model = diff.apply_to(self._idom_model)
                 for v_id in self._idom_views:
-                    self.send({"viewID": v_id, "data": update})
+                    self.send({"viewID": v_id, "data": diff})
+
+    def __repr__(self) -> str:
+        return f"LayoutWidget({self._idom_layout})"
 
 
 def _spawn_threaded_event_loop(coro):
