@@ -5,21 +5,22 @@
 // Some static assets may be required by the custom widget javascript. The base
 // url for the notebook is not known at build time and is therefore computed
 // dynamically.
-__webpack_public_path__ = document.querySelector('body').getAttribute('data-base-url') + 'nbextensions/idom-client-jupyter';
-
+__webpack_public_path__ =
+  document.querySelector("body").getAttribute("data-base-url") +
+  "nbextensions/idom-client-jupyter";
 
 // Configure requirejs
 if (window.require) {
-    window.require.config({
-        map: {
-            "*" : {
-                "idom-client-jupyter": "nbextensions/idom-client-jupyter/index",
-            }
-        }
-    });
+  window.require.config({
+    map: {
+      "*": {
+        "idom-client-jupyter": "nbextensions/idom-client-jupyter/index",
+      },
+    },
+  });
 }
 
 // Export the required load_ipython_extension
 module.exports = {
-    load_ipython_extension: function() {}
+  load_ipython_extension: function () {},
 };
